=======================================================
 cliff -- Command Line Interface Formulation Framework
=======================================================

cliff is a framework for building command line programs. It uses
plugins to define sub-commands, output formatters, and other
extensions.

Contents:

.. toctree::
   :maxdepth: 2

   introduction
   demoapp
   list_commands
   show_commands
   interactive_mode
   classes
   install
   developers
   history


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. todolist::
